SnapHelper class

Snap logic for aligning shapes to each other and grids.

Constructors

SnapHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getClosestSnapPoint(Offset point, List<DrawnShape> shapes, DrawnShape? excludeShape, {double threshold = 20.0}) Offset?
getSnapPoint(Offset movingStart, Offset movingEnd, DrawnShape movingShape, List<DrawnShape> allShapes, double snapThreshold) Offset?
snapToGrid(Offset point, double gridSize) Offset